function [tn, yn] = eulimp (t0, y0, tf, h, f)
%
%    Metodo di eulero implicito
%
%        [tn, yn] = eulimp (t0, y0, tf, h, f)
%
% Parametri in ingresso
%   t0, y0  condizioni iniziali (u_0 = y0(t0))
%   tf      estremo di integrazione
%   h       passo di integrazione
%   f       macro contenente la funzione del problema di Cauchy
%  il problema non-lineare viene risolto con la funzione fzero di Matlab
% 
% Parametri in uscita
%  tn       ascisse di valutazione
%  yn  valori della soluzione calcolata
%
clear tn yn fun

n=fix(abs(tf-t0)/h);
tn(1) = t0;
yn(1) = y0;

for i=2:n           
    tn(i) = tn(i-1) + h; 
    t=tn(i);
    ff=f;
    for jj=1:length(ff), 
        if(ff(jj)=='t'), ff(jj)=num2str(t,16); end,
        if(ff(jj)=='y'), ff(jj)='x'; end    
    end
    fun=strcat('x-',num2str(h,16),'*',ff,'-',num2str(yn(i-1),16));
    zero=fzero(fun,yn(i-1));         
    yn(i)=zero;     
end

return
