function [zero,xvect,xdif,fx,it]=newton1(xv,nmax,toll,fun,dfun)
%
%  [zero,xvect,xdif,fx,it]=newton1(xv,nmax,toll,fun,dfun)
%
%  Metodo di Newton per la ricerca degli zeri della
%  funzione fun. Test d'arresto basato sul controllo
%  della differenza tra due iterate successive.
%
%  Parametri di ingresso:
%
%  xv         Punto di partenza
%  nmax       Numero massimo di iterazioni
%  toll       Tolleranza sul test d'arresto
%  fun dfun   Macro contenenti la funzione e la sua derivata
%
%  Parametri di uscita:
%
%  zero     Zero calcolato
%  xvect      Vett. contenente tutte le iterate calcolate
%             (l'ultima componente e' la soluzione)
%  xdif       Vett. contenente l'avanzamento tra due iterate
%  fx         Vett. contenente le valutazioni di 'fun' in 'xvect'
%  it         Iterazioni effettuate
%
err=1;
it=0;
x=xv;
fxv=eval(fun);
xvect=[xv];
fx=[fxv];
xdif=0;
%
while it<nmax & err>toll
   x=xv;
   dfx=eval(dfun);
   if dfx == 0
      disp(' Arresto per azzeramento di dfun');
      it=it+1;
      break
   else
      xn=xv-2*fxv/dfx;
      %test d'arresto ||xn-xv||<toll
      err=abs(xn-xv);
      xdif=[xdif;err];
      x=xn;
      fxv=eval(fun);
      xvect=[xvect;xn];
      fx=[fx;fxv];
      it=it+1;
      xv=xn;
   end
end
%

fprintf(' \n Numero di Iterazioni : %d \n',it);
fprintf(' Zero calcolato     : %20.16f \n',xvect(end));
fprintf(' f(zero calcolato)  : %20.16f \n', fx(end));
zero=xvect(end);
%
return

