function [zero,xvect,xdif,fx,stimatore,it]=newton2(xv,nmax,toll,fun,dfun)
%
%  [zero,xvect,xdif,fx,stimatore,it]=newton2(xv,nmax,toll,fun,dfun)
%
%  Metodo di Newton per la ricerca degli zeri della
%  funzione fun. Test d'arresto basato sul controllo
%  della funzione f valutata nella zero calcolata.
%
%  Parametri di ingresso:
%
%  xv         Punto di partenza
%  nmax       Numero massimo di iterazioni
%  toll       Tolleranza sul test d'arresto
%  fun dfun   Macro contenenti la funzione e la sua derivata
%
%  Parametri di uscita:
%
%  zero     zero calcolato
%  xvect      Vett. contenente tutte le iterate calcolate
%             (l'ultima componente e' la soluzione)
%  xdif       Vett. contenente l'avanzamento tra due iterate
%  fx         Vett. contenente le valutazioni di 'fun' in 'xvect'
%  stimatore  Vett. contenente abs(f(xk))
%  it         Iterazioni effettuate
%
errf=1;
err=1;
it=0;
x=xv;
fxv=eval(fun);
stimatore=[abs(fxv)];
xvect=[xv];
fx=[fxv];
xdif=0;
%
while it<nmax & errf>toll
   x=xv;
   dfx=eval(dfun);
   if dfx == 0
      disp(' Arresto per azzeramento di dfun');
      it=it+1;
      break
   else
      xn=xv-fxv/dfx;
      err=abs(xn-xv);
      xdif=[xdif;err];
      x=xn;
      fxv=eval(fun);
      %test d'arresto abs(f(xk))<toll
      errf=abs(fxv);
      stimatore=[stimatore;errf];
      xvect=[xvect;xn];
      fx=[fx;fxv];
      it=it+1;
      xv=xn;
   end
end
%

fprintf(' \n Numero di Iterazioni : %d \n',it);
fprintf(' zero calcolato     : %20.16f \n',xvect(end));
fprintf(' f(zero calcolato)  : %20.16f \n', fx(end));
zero=xvect(end);
%
return


