function [xvect,nit] = qssnewtonxsys(x0, toll, nmax, varargin)
%
%  [xr,nit] = qssnewtonxsys(x0, toll, nmax, f1, f2, ..., fN, ...
%                           J11, J12, ..., J1N, ..., JNN )
%
%  Metodo di Newton per sistemi non lineari di dimensione N <=4
%
%  Parametri di ingresso:
%
%  varargin  lista delle macro contenenti le N equazioni del sistema
%            f1, f2, ... fN e le N^2 componenti della jacobiana 
%            scandita per righe J11 = df1/dx1, J12 = df1/dx2, ...., 
%            J1N = df1/dxN, ...., JNN = dfN/dxN.
%  x0        vett. colonna di dimensione N, contenente il dato iniziale
%  toll      tolleranza
%  nmax      numero massimo iterazioni
%
%  Parametri di uscita:
%
%  xvect matrice di N colonne contenente le radici calcolate 
%  nit   numero iterazioni
%
N = (-1 + sqrt(4*(nargin-3)+1))/2;
% allineamento equazioni del sistema
maxL = 0;
for i = 1:N
  if length(varargin{i}) > maxL
     maxL = length(varargin{i});
  end
end
for i = 1:N
  extra(i) = maxL - length(varargin{i});
  for j = 1:extra(i)
    varargin{i} = cat(2,varargin{i},' ');
  end
end
f = cat(1,varargin{1:N});
% allineamento jacobiana del sistema
maxL = 0;
for i = 1:N^2
  if length(varargin{i+N}) > maxL
     maxL = length(varargin{i+N});
  end
end
for i = 1:N^2
  extra(i) = maxL - length(varargin{i+N});
  for j = 1:extra(i)
    varargin{i+N} = cat(2,varargin{i+N},' ');
  end
end
jac = cat(1,varargin{N+1:N+N^2});
[n,m]=size(f);
nit=1;
epi=1;
fxn=zeros(n,1);
x1=x0;
xvect=x0';
%
while norm(epi)>toll;
  x=x1;
  for i=1:n;
   fxn(i)=eval(f(i,:));
   for j=1:n;
    axn(i,j)=eval(jac((i-1)*n+j,:));
   end;
  end;
  epi=axn\fxn;
  x1=x-epi;
  xvect=[xvect; x1'];
  nit=nit+1;
%
  if nit>nmax;
     disp('* errore * non converge');
     break;
  end;
end;
%
fprintf(' \n Numero di Iterazioni : %d \n',nit-1);
for i=1:n,
  fprintf(' x(%d) = %12.8f \n',i, xvect(nit,i));
end
return
